# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['plumage']

package_data = \
{'': ['*'],
 'plumage': ['static/css/*', 'static/img/*', 'static/js/*', 'templates/*']}

install_requires = \
['pelican>=4.2.0,<5.0.0']

setup_kwargs = {
    'name': 'plumage',
    'version': '1.0.0',
    'description': 'Clean and tidy theme for Pelican.',
    'long_description': 'Plumage\n=======\n\nPlumage is a theme for [Pelican](https://getpelican.com), a static site\ngenerator written in Python.\n\nI initially created this theme for [my blog](https://kevin.deldycke.com), but\nnow the theme is supposed to be generic enough to have its own repository.\n\n![Plumage article view\n](https://raw.githubusercontent.com/kdeldycke/plumage/master/plumage-article-screenshot.png)\n\n\nFeatures\n--------\n\n  * Based on [Bootstrap v3](https://getbootstrap.com).\n  * [Solarized](https://ethanschoonover.com/solarized) code snippets via\n    [Pygments](https://pygments.org/) for syntax highlighting.\n  * Site-wide static search via [Tipue-search](https://www.tipue.com/search/).\n  * Project template.\n  * Tags grouped by tiers.\n  * External assets (Bootstrap, Jquery, etc...) uses [CDNjs\n  ](https://cdnjs.com/about).\n  * YouTube links.\n  * Direct link to edit articles on Github.\n\n\nPlugins\n-------\n\nPlumage has built-in support for the following plugins:\n\n  * [`tipue_search`\n  ](https://github.com/getpelican/pelican-plugins/tree/master/tipue_search)\n  * [`neighbors`\n  ](https://github.com/getpelican/pelican-plugins/tree/master/neighbors)\n  * [`related_posts`\n  ](https://github.com/getpelican/pelican-plugins/tree/master/related_posts)\n  * [`typogrify`](https://pypi.python.org/pypi/typogrify)\n\n\nInstallation\n------------\n\nThis package is [available on PyPi](https://pypi.python.org/pypi/plumage), so\nyou can install the\nlatest stable release and its dependencies with a simple ``pip`` call:\n\n```python\n$ pip install plumage\n```\n\nThen, update your `pelicanconf.py` file, with the module:\n\n```python\nimport plumage\n\nTHEME = plumage.get_path()\n```\n\n\nSettings\n--------\n\nPlumage can be customized by adding these optionnal parameters to your\n`pelicanconf.py` file:\n\nSetting name | Default value | Description\n:--- |:--- |:---\n`ARTICLE_EDIT_LINK` | | Generate an edit link besides each article. Can use `%(slug)s` to include dynamic article\'s slug in the link.\n`COPYRIGHT` | | Additional copyright statement to add in the third column of the footer.\n`DISCLAIMER` | | Overide the Disclaimer notice that gets displayed at the fourth column of the footer.\n[`DISQUS_SITENAME`](http://docs.getpelican.com/en/stable/settings.html#DISQUS_SITENAME) | | Pelican can handle Disqus comments. Specify the Disqus sitename identifier here.\n`FAVICON_LINKS` | `True` | Fetch link\'s icons from [Google\'s favicons webservice](https://www.google.com/s2/favicons).\n`FLAT_DESIGN` | `True` | Should we use the default Bootstrap theme, effectively rendering widgets in a flat-style design or not.\n[`GOOGLE_ANALYTICS`](http://docs.getpelican.com/en/stable/settings.html#GOOGLE_ANALYTICS) | | Set to `UA-XXXXX-Y` Property\'s tracking ID to activate Google Analytics.\n[`GA_COOKIE_DOMAIN`](http://docs.getpelican.com/en/stable/settings.html#GA_COOKIE_DOMAIN) | `auto` | Set cookie domain field of Google Analytics tracking code.\n`GOOGLE_SEARCH` | | [Google\'s Custom Search Engine](https://www.google.com/cse/) ID (e.g. `partner-pub-0123456789098765:0123456789`) to activate blog specific search.\n`LEFT_SIDEBAR` | | HTML content to put as-is in the left sidebar.\n[`LINKS_WIDGET_NAME`](http://docs.getpelican.com/en/stable/settings.html#LINKS_WIDGET_NAME) | `"Links"` | Allows override of the name of the links widget.\n[`LINKS`](http://docs.getpelican.com/en/stable/settings.html#LINKS) | | A list of tuples (Title, URL) for links to appear in the second column of the footer.\n[`MANUAL_LINKS`](http://docs.getpelican.com/en/stable/settings.html#MANUAL_LINKS) | | When enabling this, you must pass the links (in LINKS & SOCIAL settins) not as tuples anymore, but as list, where every entry is formatted as you like\n[`MENUITEMS`](http://docs.getpelican.com/en/stable/settings.html#MENUITEMS) | | A list of tuples (Title, URL) for additional menu items to appear at the beginning of the main menu.\n[`PIWIK_SITE_ID`](http://docs.getpelican.com/en/stable/settings.html#PIWIK_SITE_ID) | | ID for the monitored website. You can find the ID in the Piwik admin interface > Settings > Websites.\n[`PIWIK_SSL_URL`](http://docs.getpelican.com/en/stable/settings.html#PIWIK_SSL_URL) | | If the SSL-URL differs from the normal Piwik-URL you have to include this setting too. (optional)\n[`PIWIK_URL`](http://docs.getpelican.com/en/stable/settings.html#PIWIK_URL) | | URL to your [Piwik](https://piwik.org) server - without `https://` at the beginning.\n`RIGHT_SIDEBAR` | | HTML content to put as-is in the right sidebar.\n[`SITESUBTITLE`](http://docs.getpelican.com/en/stable/settings.html#SITESUBTITLE) | | A subtitle to appear in the header.\n`SITE_THUMBNAIL_TEXT` | | Text displayed behind site\'s thumbnail.\n`SITE_THUMBNAIL` | | Site\'s thumbnail URL as displayed in the header. Should be a square image of at least 80x80 pixels.\n[`SOCIAL_WIDGET_NAME`](http://docs.getpelican.com/en/stable/settings.html#SOCIAL_WIDGET_NAME) | `"Social"` | Allows override of the name of the “social” widget.\n[`SOCIAL`](http://docs.getpelican.com/en/stable/settings.html#SOCIAL) | | A list of tuples (Title, URL) to appear in the first columns of the footer.\n`TIPUE_SEARCH` | `False` | Activate [Tipue Search](https://www.tipue.com/search) (javascript search engine) into the site. Requires the [`tipue_search`](https://github.com/getpelican/pelican-plugins/tree/master/tipue_search) plugin.\n\nMost of these [parameters are similar to `notmyidea`\'s\n](https://docs.getpelican.com/en/latest/settings.html#themes) (Pelican\'s default\ntheme). For usage example, please have a look into [my own `pelicanconf.py`\n](https://github.com/kdeldycke/kevin-deldycke-blog/blob/master/pelicanconf.py).\n\nThe theme is also sensible to this list of [standard Pelican parameters\n](https://docs.getpelican.com/en/latest/settings.html):\n\n  * `ARCHIVES_SAVE_AS`\n  * `AUTHOR`\n  * `AUTHOR_SAVE_AS`\n  * `AUTHORS_SAVE_AS`\n  * `CATEGORIES_SAVE_AS`\n  * `CATEGORY_FEED_ATOM`\n  * `CATEGORY_FEED_RSS`\n  * `DEFAULT_LANG`\n  * `DEFAULT_PAGINATION`\n  * `DISPLAY_PAGES_ON_MENU`\n  * `DISPLAY_CATEGORIES_ON_MENU`\n  * `FEED_ALL_ATOM`\n  * `FEED_ALL_RSS`\n  * `FEED_ATOM`\n  * `FEED_DOMAIN`\n  * `FEED_RSS`\n  * `PAGINATION_PATTERNS`\n  * `SITENAME`\n  * `SITEURL`\n  * `TAG_FEED_ATOM`\n  * `TAG_FEED_RSS`\n  * `TAGS_SAVE_AS`\n  * `TYPOGRIFY`\n\n\n### Common pitfalls\n\nSome plugins may need additional settings, for instance for **tipue_search**,\nafter applying the standard options:\n\n```python\nPLUGINS = [\'tipue_search\']\nTIPUE_SEARCH = True\n```\n\n... you\'ll need to declare additional template file,\nby either adding this line to your `pelicanconf.py`:\n\n```python\nTEMPLATE_PAGES = {\n        \'search.html\': \'search.html\',\n        }\n```\n\nor using [this technique](https://github.com/kdeldycke/kevin-deldycke-blog/commit/cd4bf8d1f4c55d835d7bfe1d7233cffe48e67a8a).\n\n\nFAQ\n---\n\n**How can I disable the zoom on images?**\n\nAll images of an article are zoomable by default. You can deactivate the\nmagnifying glass per-image by adding a `noZoom` CSS class. So instead of the\nfollowing Markdown code:\n\n    ![Image title](/folder/image.png)\n\nYou have to use the following template to deactivate the zoom of an image:\n\n    ![Image title](/folder/image.png){: .noZoom}\n\n\nLicense\n-------\n\nThis software is licensed under the [GNU General Public License v2 or later\n(GPLv2+)](https://github.com/kdeldycke/plumage/blob/master/LICENSE).\n\nCopyright (C) 2012-2017 [Kevin Deldycke](https://kevin.deldycke.com) and\n[contributors](https://github.com/kdeldycke/plumage/graphs/contributors). All\nRights Reserved.\n\n\nThird-party assets\n------------------\n\nThe theme uses external softwares, scripts, libraries and artworks:\n\n    jQuery MGlass v1.1\n    Copyright (c) 2012 Younès El Biache\n    Distributed under a MIT license\n    Source: https://github.com/younes0/jQuery-MGlass\n\n    Solarized Pygment style v0.1.0\n    Copyright (c) 2012 Shoji KUMAGAI\n    Distributed under a MIT license\n    Source: https://pypi.python.org/pypi/pygments-style-solarized\n\n    Fabric (Plaid)\n    Copyright (c) 2012 James Basoo\n    Distributed under a Creative Commons Attribution-ShareAlike 3.0 Unported license\n    Source: https://subtlepatterns.com/fabric-plaid/\n\n    Cream paper\n    Copyright (c) 2012 Devin Holmes\n    Distributed under a Creative Commons Attribution-ShareAlike 3.0 Unported license\n    Source: https://subtlepatterns.com/cream-paper/\n',
    'author': 'Kevin Deldycke',
    'author_email': 'kevin@deldycke.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/kdeldycke/plumage',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
